# Orange3-Replace-Text

This simple widget allows you to replace words in a Corpus with alternatives.

Within the Add-ons installer, click on "Add more..." and type in Orange3-Replace-Text

![Installation Screenshot](https://github.com/chrislee35/orange3-replace-text/blob/main/imgs/install_orange3_replace_text.png?raw=true)
